@@ -9,7 +9,7 @@
 
 __all__ = ["MokeError", "task", "stdin", "stdout", "stderr", "num", "doc",
            "INFO", "WARN", "ERROR"]
-__version__ = "1.1.1"
+__version__ = "1.1.2"
 
 
 import os
@@ -314,9 +314,9 @@ class task(object):
 
         try:
             # works on linux 3
-            stdin_name = os.readlink('/dev/fd/0')
-            stdout_name = os.readlink('/dev/fd/1')
-            stderr_name = os.readlink('/dev/fd/2')
+            stdin_name = os.readlink('/dev/stdin')
+            stdout_name = os.readlink('/dev/stdout')
+            stderr_name = os.readlink('/dev/stderr')
 
         except:
             stdin_name,stdout_name,stderr_name = "","",""
